# Generated by Django 2.1.7 on 2019-02-13 11:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('journal', '0009_auto_20190211_1515'),
    ]

    operations = [
        migrations.AddField(
            model_name='journalmember',
            name='readOnly',
            field=models.BooleanField(default=False),
        ),
    ]
