# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-17 16:16
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('journal', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='entry',
            options={'ordering': ['id']},
        ),
    ]
